@@ -7,6 +7,7 @@
 import subprocess
 
 from selenium.webdriver import Remote
+from selenium.webdriver.common.desired_capabilities import DesiredCapabilities
 from splinter.driver.webdriver import BaseWebDriver, WebDriverElement as BaseWebDriverElement
 from splinter.cookie_manager import CookieManagerAPI
 
@@ -14,20 +15,19 @@ from splinter.cookie_manager import CookieManagerAPI
 class WebDriver(BaseWebDriver):
 
     driver_name = "Remote webdriver"
+    # TODO: This constant belongs in selenium.webdriver.Remote
+    DEFAULT_URL = 'http://127.0.0.1:4444/wd/hub'
 
-    def __init__(self, server='localhost', port=4444):
-        self.old_popen = subprocess.Popen
-
-        self._patch_subprocess()
-        dest = 'http://%s:%s/wd/hub' % (server, port)
-        self.driver = Remote(dest, {})
-        self._unpatch_subprocess()
+    def __init__(self, url=DEFAULT_URL, browser='firefox', wait_time=2, **ability_args):
+        abilities = getattr(DesiredCapabilities, browser.upper(), {})
+        abilities.update(ability_args)
+        self.driver = Remote(url, abilities)
 
         self.element_class = WebDriverElement
 
         self._cookie_manager = CookieManagerAPI()
 
-        super(WebDriver, self).__init__()
+        super(WebDriver, self).__init__(wait_time)
 
 
 class WebDriverElement(BaseWebDriverElement):
